@@ -21,15 +21,19 @@
 
 """Generate and process backup statistics"""
 
-import re, time, os
+from future_builtins import map
+
+import re
+import time
+import os
 
-from duplicity import lazy
 from duplicity import dup_time
 
 
 class StatsException(Exception):
     pass
 
+
 class StatsObj:
     """Contains various statistics, provide string conversion functions"""
     # used when quoting files in get_stats_line
@@ -67,9 +71,9 @@ class StatsObj:
                        ('RawDeltaSize', True))
 
     # This is used in get_byte_summary_string below
-    byte_abbrev_list = ((1024*1024*1024*1024, "TB"),
-                        (1024*1024*1024, "GB"),
-                        (1024*1024, "MB"),
+    byte_abbrev_list = ((1024 * 1024 * 1024 * 1024, "TB"),
+                        (1024 * 1024 * 1024, "GB"),
+                        (1024 * 1024, "MB"),
                         (1024, "KB"))
 
     def __init__(self):
@@ -96,21 +100,20 @@ class StatsObj:
         duplicity destination directory, or None if not available.
 
         """
-        return 0 # this needs to be re-done for duplicity
+        return 0  # this needs to be re-done for duplicity
 
-    def get_stats_line(self, index, use_repr = 1):
+    def get_stats_line(self, index, use_repr=1):
         """Return one line abbreviated version of full stats string"""
-        file_attrs = map(lambda attr: str(self.get_stat(attr)),
-                         self.stat_file_attrs)
+        file_attrs = [str(self.get_stat(a)) for a in self.stat_file_attrs]
         if not index:
             filename = "."
         else:
-            filename = apply(os.path.join, index)
+            filename = os.path.join(*index)
             if use_repr:
                 # use repr to quote newlines in relative filename, then
                 # take of leading and trailing quote and quote spaces.
                 filename = self.space_regex.sub("\\x20", repr(filename)[1:-1])
-        return " ".join([filename,] + file_attrs)
+        return " ".join([filename, ] + file_attrs)
 
     def set_stats_from_line(self, line):
         """Set statistics from given line"""
@@ -119,12 +122,12 @@ class StatsObj:
         if line[-1] == "\n":
             line = line[:-1]
         lineparts = line.split(" ")
-        if len(lineparts) < len(stat_file_attrs):
+        if len(lineparts) < len(self.stat_file_attrs):
             error()
-        for attr, val_string in zip(stat_file_attrs,
-                                    lineparts[-len(stat_file_attrs):]):
+        for attr, val_string in zip(self.stat_file_attrs,
+                                    lineparts[-len(self.stat_file_attrs):]):
             try:
-                val = long(val_string)
+                val = int(val_string)
             except ValueError:
                 try:
                     val = float(val_string)
@@ -144,16 +147,16 @@ class StatsObj:
         timelist = []
         if self.StartTime is not None:
             timelist.append("StartTime %.2f (%s)\n" %
-                     (self.StartTime, dup_time.timetopretty(self.StartTime)))
+                            (self.StartTime, dup_time.timetopretty(self.StartTime)))
         if self.EndTime is not None:
             timelist.append("EndTime %.2f (%s)\n" %
-                         (self.EndTime, dup_time.timetopretty(self.EndTime)))
+                            (self.EndTime, dup_time.timetopretty(self.EndTime)))
         if self.ElapsedTime or (self.StartTime is not None and
                                 self.EndTime is not None):
             if self.ElapsedTime is None:
                 self.ElapsedTime = self.EndTime - self.StartTime
             timelist.append("ElapsedTime %.2f (%s)\n" %
-                 (self.ElapsedTime, dup_time.inttopretty(self.ElapsedTime)))
+                            (self.ElapsedTime, dup_time.inttopretty(self.ElapsedTime)))
         return "".join(timelist)
 
     def get_filestats_string(self):
@@ -194,7 +197,7 @@ class StatsObj:
         for abbrev_bytes, abbrev_string in self.byte_abbrev_list:
             if byte_count >= abbrev_bytes:
                 # Now get 3 significant figures
-                abbrev_count = float(byte_count)/abbrev_bytes
+                abbrev_count = float(byte_count) / abbrev_bytes
                 if abbrev_count >= 100:
                     precision = 0
                 elif abbrev_count >= 10:
@@ -227,18 +230,18 @@ class StatsObj:
             if len(line_parts) < 2:
                 error(line)
             attr, value_string = line_parts[:2]
-            if not attr in self.stat_attrs:
+            if attr not in self.stat_attrs:
                 error(line)
             try:
                 try:
-                    val1 = long(value_string)
+                    val1 = int(value_string)
                 except ValueError:
                     val1 = None
                 val2 = float(value_string)
                 if val1 == val2:
-                    self.set_stat(attr, val1) # use integer val
+                    self.set_stat(attr, val1)  # use integer val
                 else:
-                    self.set_stat(attr, val2) # use float
+                    self.set_stat(attr, val2)  # use float
             except ValueError:
                 error(line)
         return self
@@ -283,12 +286,12 @@ class StatsObj:
         for attr in self.stat_attrs:
             if self.get_stat(attr) is not None:
                 self.set_stat(attr,
-                              self.get_stat(attr)/float(len(statobj_list)))
+                              self.get_stat(attr) / float(len(statobj_list)))
         return self
 
     def get_statsobj_copy(self):
         """Return new StatsObj object with same stats as self"""
-        s = StatObj()
+        s = StatsObj()
         for attr in self.stat_attrs:
             s.set_stat(attr, self.get_stat(attr))
         return s
@@ -324,7 +327,7 @@ class StatsDeltaProcess(StatsObj):
 
     def add_deleted_file(self):
         """Add stats of file no longer in source directory"""
-        self.DeletedFiles += 1 # can't add size since not available
+        self.DeletedFiles += 1  # can't add size since not available
         self.DeltaEntries += 1
 
     def add_unchanged_file(self, path):
@@ -336,4 +339,3 @@ class StatsDeltaProcess(StatsObj):
     def close(self):
         """End collection of data, set EndTime"""
         self.EndTime = time.time()
-
